MAUD
====

Welcome to MAUD, Moving Average of Uneven Data


Maud was also a ship built by Amundsen. http://en.wikipedia.org/wiki/Maud_(ship). Dr. Sverdrup was first a meteorologist, but changed interest to oceanography while in charge of the scientific work on the north pole expedition leaded by Amundsen, aboard the Maud (Cushman-Roisin, 1994).
